@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2007  NTT DATA CORPORATION
  *
- * Version: 1.4.1   2007/06/05
+ * Version: 1.4.3   2007/11/11
  *
  */
 #include "ccstools.h"
@@ -900,7 +900,7 @@ static void ReadDomainAndExceptionPolicy(void) {
 	ClearDomainPolicy();
 	domain_keeper_list_len = 0;
 	domain_initializer_list_len = 0;
-	group_list_len = 0;
+	while (group_list_len) free(group_list[--group_list_len].member_name);
 	FindOrAssignNewDomain(ROOT_NAME, 0, 0);
 
 	// Load domain_initializer list, domain_keeper list.
@@ -1807,7 +1807,10 @@ int editpolicy_main(int argc, char *argv[]) {
 		if (!offline_mode) {
 			if (current_screen == SCREEN_DOMAIN_LIST && access(DOMAIN_POLICY_FILE, F_OK)) current_screen = SCREEN_SYSTEM_LIST;
 			else if (current_screen == SCREEN_SYSTEM_LIST && access(SYSTEM_POLICY_FILE, F_OK)) current_screen = SCREEN_EXCEPTION_LIST;
-			else if (current_screen == SCREEN_EXCEPTION_LIST && access(EXCEPTION_POLICY_FILE, F_OK)) current_screen = SCREEN_DOMAIN_LIST;
+			else if (current_screen == SCREEN_EXCEPTION_LIST && access(EXCEPTION_POLICY_FILE, F_OK)) {
+				current_screen = SCREEN_DOMAIN_LIST;
+				if (access(DOMAIN_POLICY_FILE, F_OK)) current_screen = SCREEN_SYSTEM_LIST;
+			}
 		}
 		ResizeWindow();
 		current_screen = GenericListLoop();
